==> attal_0.8.orig.tar.gz: attal-0.8/i18n/it/scenario_editor_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>EditTroop</name>
    <message>
        <source>Race : </source>
        <translation>Specie:</translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Number : </source>
        <translation>Numero:</translation>
    </message>
</context>
<context>
    <name>FillDialog</name>
    <message>
        <source>Choose tile</source>
        <translation>Scegli il tipo di suolo</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>PropertiesBase</name>
    <message>
        <source>Base properties</source>
        <translation>Proprietà del castello</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Proprietario:</translation>
    </message>
    <message>
        <source>Buildings</source>
        <translation>Edificio</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Niente</translation>
    </message>
</context>
<context>
    <name>PropertiesCreature</name>
    <message>
        <source>Number of Creatures: </source>
        <translation type="obsolete">Numero delle Creature:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Behaviour of Creatures: </source>
        <translation>Comportamento delle creature:</translation>
    </message>
    <message>
        <source>Never flee: </source>
        <translation>Non fuggire mai:</translation>
    </message>
    <message>
        <source>Looking at right side: </source>
        <translation>Girato verso destra:</translation>
    </message>
    <message>
        <source>Number of creatures in stack %d: </source>
        <translation>Numero di creature nella pila %d:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>PropertiesLord</name>
    <message>
        <source>Lord properties</source>
        <translation>Proprietà del signore</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Units</source>
        <translation>Unità</translation>
    </message>
    <message>
        <source>Artefacts</source>
        <translation>Artefatti</translation>
    </message>
    <message>
        <source>War Machines</source>
        <translation>Macchine da guerra</translation>
    </message>
    <message>
        <source>Technics</source>
        <translation>Tecniche</translation>
    </message>
    <message>
        <source>Lord&apos;s properties error</source>
        <translation>Errore nelle proprietà del signore</translation>
    </message>
    <message>
        <source>The lord must have at least 1 unit</source>
        <translation>Il signore deve avere almeno un&apos;unità</translation>
    </message>
</context>
<context>
    <name>PropertiesLordArtefacts</name>
    <message>
        <source>Common artefacts list</source>
        <translation>Lista degli artefatti disponibili</translation>
    </message>
    <message>
        <source>Lord&apos;s artefacts list</source>
        <translation>Lista degli artefatti del signore</translation>
    </message>
</context>
<context>
    <name>PropertiesLordGeneral</name>
    <message>
        <source>Select player:</source>
        <translation>Scegli il giocatore:</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Default</translation>
    </message>
</context>
<context>
    <name>PropertiesLordTechnics</name>
    <message>
        <source>Common technics list</source>
        <translation>Lista delle tecniche disponibili</translation>
    </message>
    <message>
        <source>Lord&apos;s technics list</source>
        <translation>Lista delle tecniche del signore</translation>
    </message>
</context>
<context>
    <name>PropertiesLordWarMachines</name>
    <message>
        <source>Common war machines list</source>
        <translation>Lista delle macchine da guerra disponibili</translation>
    </message>
    <message>
        <source>Lord&apos;s war machines list</source>
        <translation>Lista delle macchine da guerra del signore</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Tile</source>
        <translation>Suolo</translation>
    </message>
    <message>
        <source>Transition</source>
        <translation>Transizione</translation>
    </message>
    <message>
        <source>Decoration</source>
        <translation>Decorazione</translation>
    </message>
    <message>
        <source>Building</source>
        <translation>Edificio</translation>
    </message>
    <message>
        <source>Base</source>
        <translation>Castello</translation>
    </message>
    <message>
        <source>Lord</source>
        <translation>Signore</translation>
    </message>
    <message>
        <source>Artefact</source>
        <translation>Artefatto</translation>
    </message>
    <message>
        <source>Bonus</source>
        <translation>Bonus</translation>
    </message>
    <message>
        <source>Creature</source>
        <translation>Creatura</translation>
    </message>
    <message>
        <source>Tool</source>
        <translation>Strumento</translation>
    </message>
</context>
<context>
    <name>ScenarioInfo</name>
    <message>
        <source>General Scenario Informations</source>
        <translation>Informazioni generali sullo scenario</translation>
    </message>
    <message>
        <source>General Information</source>
        <translation>Informazioni generali</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Theme: </source>
        <translation>Tema:</translation>
    </message>
    <message>
        <source>Number of players: </source>
        <translation>Numero dei giocatori:</translation>
    </message>
    <message>
        <source>Map height: </source>
        <translation>Altezza della mappa:</translation>
    </message>
    <message>
        <source>Map width: </source>
        <translation>Larghezza della mappa:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Descrizione:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Map </source>
        <translation>Mappa</translation>
    </message>
    <message>
        <source>Map for Attal</source>
        <translation>Mappa per Attal</translation>
    </message>
</context>
<context>
    <name>ScenarioInterface</name>
    <message>
        <source>New</source>
        <translation>Nuovo</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuovo</translation>
    </message>
    <message>
        <source>CTRL+N</source>
        <translation>CTRL+N</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Apri</translation>
    </message>
    <message>
        <source>CTRL+O</source>
        <translation>CTRL+O</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Salva</translation>
    </message>
    <message>
        <source>CTRL+S</source>
        <translation>CTRL+S</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation>Salva con nome</translation>
    </message>
    <message>
        <source>&amp;Save as</source>
        <translation>&amp;Salva con nome</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>Scenario information</source>
        <translation>Informazioni sullo scenario</translation>
    </message>
    <message>
        <source>&amp;Scenario information</source>
        <translation>&amp;Informazioni sullo scenario</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Players properties</source>
        <translation>Proprietà dei giocatori</translation>
    </message>
    <message>
        <source>&amp;Players properties</source>
        <translation>&amp;Proprietà dei giocatori</translation>
    </message>
    <message>
        <source>CTRL+P</source>
        <translation>CTRL+P</translation>
    </message>
    <message>
        <source>Clear screen</source>
        <translation>Pulisci lo schermo</translation>
    </message>
    <message>
        <source>&amp;Clear screen</source>
        <translation>&amp;Pulisci lo schermo</translation>
    </message>
    <message>
        <source>CTRL+C</source>
        <translation>CTRL+C</translation>
    </message>
    <message>
        <source>Fill screen</source>
        <translation>Riempi lo schermo</translation>
    </message>
    <message>
        <source>&amp;Fill screen</source>
        <translation>&amp;Riempi lo schermo</translation>
    </message>
    <message>
        <source>CTRL+F</source>
        <translation>CTRL+F</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Scenario</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Strumenti</translation>
    </message>
</context>
<context>
    <name>TilePresentation</name>
    <message>
        <source>%d (weight=%d)</source>
        <translation>%d (peso=%d)</translation>
    </message>
</context>
</TS>

==> attal_0.9.1.orig.tar.gz: attal-0.9.1/i18n/it/scenario_editor_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>AskLordCharac</name>
    <message>
        <source>Charac</source>
        <translation>Caratteristica</translation>
    </message>
</context>
<context>
    <name>DisplayQuests</name>
    <message>
        <source>Main quest: </source>
        <translation>Missione Principale:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <source>Other quests:</source>
        <translation>Altre missioni:</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>EditTroop</name>
    <message>
        <source>Race : </source>
        <translation>Specie:</translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Number : </source>
        <translation>Numero:</translation>
    </message>
</context>
<context>
    <name>FillDialog</name>
    <message>
        <source>Choose tile</source>
        <translation>Scegli il tipo di suolo</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>%d (weight=%d)</source>
        <translation>%d (peso=%d)</translation>
    </message>
</context>
<context>
    <name>NewQuestConditionDialog</name>
    <message>
        <source>AND</source>
        <translation>E</translation>
    </message>
    <message>
        <source>OR</source>
        <translation>O</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Incontro</translation>
    </message>
    <message>
        <source>Lord</source>
        <translation>Signore</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Giocatore</translation>
    </message>
</context>
<context>
    <name>PropertiesBase</name>
    <message>
        <source>Base properties</source>
        <translation>Proprietà del castello</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Proprietario:</translation>
    </message>
    <message>
        <source>Buildings</source>
        <translation>Edificio</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Niente</translation>
    </message>
</context>
<context>
    <name>PropertiesBonus</name>
    <message>
        <source>Resource: </source>
        <translation>Risorsa:</translation>
    </message>
    <message>
        <source>Fixed value: </source>
        <translation>Valore fisso:</translation>
    </message>
    <message>
        <source>Primary skill: </source>
        <translation>Abilità primaria:</translation>
    </message>
    <message>
        <source>Attack</source>
        <translation>Attacco</translation>
    </message>
    <message>
        <source>Defense</source>
        <translation>Difesa</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Potenza</translation>
    </message>
    <message>
        <source>Knowledge</source>
        <translation>Conoscenza</translation>
    </message>
    <message>
        <source>Morale</source>
        <translation></translation>
    </message>
    <message>
        <source>Luck</source>
        <translation>Fortuna</translation>
    </message>
    <message>
        <source>Add value: </source>
        <translation>Aggiungi valore:</translation>
    </message>
    <message>
        <source>Bonus for secondary skills are not yet implemented</source>
        <translation>I bonus per le abilità secondarie non sono ancora stati implementati</translation>
    </message>
    <message>
        <source>Bonus for spells are not yet implemented</source>
        <translation>I bonus per le magie non sono ancora stati implementati</translation>
    </message>
</context>
<context>
    <name>PropertiesBuilding</name>
    <message>
        <source>building properties</source>
        <translation>Proprietà dell&apos;edificio</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Proprietario:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Niente</translation>
    </message>
</context>
<context>
    <name>PropertiesCreature</name>
    <message>
        <source>Number of Creatures: </source>
        <translation type="obsolete">Numero delle Creature:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Behaviour of Creatures: </source>
        <translation>Comportamento delle creature:</translation>
    </message>
    <message>
        <source>Never flee: </source>
        <translation>Non fuggire mai:</translation>
    </message>
    <message>
        <source>Looking at right side: </source>
        <translation>Girato verso destra:</translation>
    </message>
    <message>
        <source>Number of creatures in stack %d: </source>
        <translation>Numero di creature nella pila %d:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>PropertiesEvent</name>
    <message>
        <source>Condition</source>
        <translation>Condizione</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>PropertiesLord</name>
    <message>
        <source>Lord properties</source>
        <translation>Proprietà del signore</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Units</source>
        <translation>Unità</translation>
    </message>
    <message>
        <source>Artefacts</source>
        <translation>Artefatti</translation>
    </message>
    <message>
        <source>War Machines</source>
        <translation>Macchine da guerra</translation>
    </message>
    <message>
        <source>Technics</source>
        <translation>Tecniche</translation>
    </message>
    <message>
        <source>Lord&apos;s properties error</source>
        <translation>Errore nelle proprietà del signore</translation>
    </message>
    <message>
        <source>The lord must have at least 1 unit</source>
        <translation>Il signore deve avere almeno un&apos;unità</translation>
    </message>
</context>
<context>
    <name>PropertiesLordArtefacts</name>
    <message>
        <source>Common artefacts list</source>
        <translation>Lista degli artefatti disponibili</translation>
    </message>
    <message>
        <source>Lord&apos;s artefacts list</source>
        <translation>Lista degli artefatti del signore</translation>
    </message>
</context>
<context>
    <name>PropertiesLordGeneral</name>
    <message>
        <source>Select player:</source>
        <translation>Scegli il giocatore:</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Default</translation>
    </message>
</context>
<context>
    <name>PropertiesLordTechnics</name>
    <message>
        <source>Common technics list</source>
        <translation>Lista delle tecniche disponibili</translation>
    </message>
    <message>
        <source>Lord&apos;s technics list</source>
        <translation>Lista delle tecniche del signore</translation>
    </message>
</context>
<context>
    <name>PropertiesLordWarMachines</name>
    <message>
        <source>Common war machines list</source>
        <translation>Lista delle macchine da guerra disponibili</translation>
    </message>
    <message>
        <source>Lord&apos;s war machines list</source>
        <translation>Lista delle macchine da guerra del signore</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Tile</source>
        <translation>Suolo</translation>
    </message>
    <message>
        <source>Transition</source>
        <translation>Transizione</translation>
    </message>
    <message>
        <source>Decoration</source>
        <translation>Decorazione</translation>
    </message>
    <message>
        <source>Building</source>
        <translation>Edificio</translation>
    </message>
    <message>
        <source>Base</source>
        <translation>Castello</translation>
    </message>
    <message>
        <source>Lord</source>
        <translation>Signore</translation>
    </message>
    <message>
        <source>Artefact</source>
        <translation>Artefatto</translation>
    </message>
    <message>
        <source>Bonus</source>
        <translation>Bonus</translation>
    </message>
    <message>
        <source>Creature</source>
        <translation>Creatura</translation>
    </message>
    <message>
        <source>Tool</source>
        <translation>Strumento</translation>
    </message>
</context>
<context>
    <name>QuestConditionDateProperties</name>
    <message>
        <source>Before date: </source>
        <translation>Prima :</translation>
    </message>
    <message>
        <source>Day</source>
        <translation>Giorno</translation>
    </message>
    <message>
        <source>Week</source>
        <translation>Settimana</translation>
    </message>
    <message>
        <source>Month</source>
        <translation>Mese</translation>
    </message>
    <message>
        <source>Before </source>
        <translation>Prima</translation>
    </message>
    <message>
        <source>day(s)</source>
        <translation>giorno(i)</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>QuestConditionDialog</name>
    <message>
        <source>Condition</source>
        <translation>Condizione</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>&amp;Properties</source>
        <translation>&amp;Proprietà</translation>
    </message>
    <message>
        <source>&amp;Add condition</source>
        <translation>&amp;Aggiungere condizione</translation>
    </message>
    <message>
        <source>&amp;Delete condition</source>
        <translation>&amp;Cancellare condizione</translation>
    </message>
</context>
<context>
    <name>QuestConditionEditor</name>
    <message>
        <source>Condition: </source>
        <translation>Condizione:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
</context>
<context>
    <name>QuestConditionLordProperties</name>
    <message>
        <source>Primary skill</source>
        <translation>Abilità primaria</translation>
    </message>
    <message>
        <source>value: </source>
        <translation>valore:</translation>
    </message>
    <message>
        <source>Secondary skill</source>
        <translation>Abilità secondaria</translation>
    </message>
    <message>
        <source>Artefact</source>
        <translation>Artefatto</translation>
    </message>
    <message>
        <source>Spell</source>
        <translation>Magia</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>QuestEditor</name>
    <message>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Descrizione:</translation>
    </message>
    <message>
        <source>Type: </source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Ask player confirmation of quest</source>
        <translation>Domanda la conferma del giocatore per la missione</translation>
    </message>
    <message>
        <source>Confirmation question: </source>
        <translation>Domanda di conferma:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Start condition: </source>
        <translation>Condizione iniziale:</translation>
    </message>
    <message>
        <source>Fail condition: </source>
        <translation>Condizione di successo:</translation>
    </message>
    <message>
        <source>Success condition: </source>
        <translation>Condizione di fallimento:</translation>
    </message>
</context>
<context>
    <name>ScenarioInfo</name>
    <message>
        <source>General Scenario Informations</source>
        <translation>Informazioni generali sullo scenario</translation>
    </message>
    <message>
        <source>General Information</source>
        <translation>Informazioni generali</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Theme: </source>
        <translation>Tema:</translation>
    </message>
    <message>
        <source>Number of players: </source>
        <translation>Numero dei giocatori:</translation>
    </message>
    <message>
        <source>Map height: </source>
        <translation>Altezza della mappa:</translation>
    </message>
    <message>
        <source>Map width: </source>
        <translation>Larghezza della mappa:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Descrizione:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Map </source>
        <translation>Mappa</translation>
    </message>
    <message>
        <source>Map for Attal</source>
        <translation>Mappa per Attal</translation>
    </message>
</context>
<context>
    <name>ScenarioInterface</name>
    <message>
        <source>New</source>
        <translation>Nuovo</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuovo</translation>
    </message>
    <message>
        <source>CTRL+N</source>
        <translation>CTRL+N</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Apri</translation>
    </message>
    <message>
        <source>CTRL+O</source>
        <translation>CTRL+O</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Salva</translation>
    </message>
    <message>
        <source>CTRL+S</source>
        <translation>CTRL+S</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation>Salva con nome</translation>
    </message>
    <message>
        <source>&amp;Save as</source>
        <translation>&amp;Salva con nome</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>Scenario information</source>
        <translation>Informazioni sullo scenario</translation>
    </message>
    <message>
        <source>&amp;Scenario information</source>
        <translation>&amp;Informazioni sullo scenario</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Players properties</source>
        <translation>Proprietà dei giocatori</translation>
    </message>
    <message>
        <source>&amp;Players properties</source>
        <translation>&amp;Proprietà dei giocatori</translation>
    </message>
    <message>
        <source>CTRL+P</source>
        <translation>CTRL+P</translation>
    </message>
    <message>
        <source>Clear screen</source>
        <translation>Pulisci lo schermo</translation>
    </message>
    <message>
        <source>&amp;Clear screen</source>
        <translation>&amp;Pulisci lo schermo</translation>
    </message>
    <message>
        <source>CTRL+C</source>
        <translation>CTRL+C</translation>
    </message>
    <message>
        <source>Fill screen</source>
        <translation>Riempi lo schermo</translation>
    </message>
    <message>
        <source>&amp;Fill screen</source>
        <translation>&amp;Riempi lo schermo</translation>
    </message>
    <message>
        <source>CTRL+F</source>
        <translation>CTRL+F</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Scenario</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Strumenti</translation>
    </message>
    <message>
        <source>Can&apos;t load theme</source>
        <translation>Non posso caricare il tema</translation>
    </message>
    <message>
        <source>Theme </source>
        <translation>Il tema </translation>
    </message>
    <message>
        <source> has not been loaded successfully</source>
        <translation> non è stato caricato con successo</translation>
    </message>
    <message>
        <source>Quests management</source>
        <translation>Gestione delle missioni</translation>
    </message>
    <message>
        <source>Mini map</source>
        <translation>Minimappa</translation>
    </message>
    <message>
        <source>&amp;Mini map</source>
        <translation>&amp;Minimappa</translation>
    </message>
    <message>
        <source>CTRL+M</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Screen</name>
    <message>
        <source>(Cell %dx%d)</source>
        <translation>(Casella %dx%d)</translation>
    </message>
</context>
<context>
    <name>TilePresentation</name>
    <message>
        <source>%d (weight=%d)</source>
        <translation>%d (peso=%d)</translation>
    </message>
</context>
</TS>
